pub struct WrapOpportunity {
pub offset: usize,
pub mandatory: bool,
}Available on crate features
analysis and unicode-wrap only.Expand description
A position in plain text where a line wrap may occur.
Fields
offset: usizeByte offset of the character that starts the new line if wrapped here.
mandatory: boolWhether the break is mandatory (e.g. a hard line feed or end of text).