Struct EncodingRule

pub struct EncodingRule;
Available on crate feature analysis only.
Rule for detecting encoding and character issues in subtitle scripts

Analyzes scripts for problematic characters that may cause encoding issues, display problems, or compatibility issues across different subtitle renderers and media players.

Encoding Checks

  • Non-printable characters: Detects control characters that shouldn’t appear in text
  • Invalid UTF-8 sequences: Identifies corrupted character data
  • Suspicious character patterns: Warns about potentially problematic sequences

Performance

  • Time complexity: O(n * m) for n events and m characters per event
  • Memory: O(1) additional space
  • Target: <2ms for typical scripts with 1000 events

Example

use ass_core::analysis::linting::rules::encoding::EncodingRule;
use ass_core::analysis::linting::LintRule;
use ass_core::{Script, ScriptAnalysis};

let script_text = format!("[Events]\nFormat: Layer, Start, End, Style, Name, MarginL, MarginR, MarginV, Effect, Text\nDialogue: 0,0:00:00.00,0:00:05.00,Default,,0,0,0,,Text with{}invalid character", '\x00');
let script = Script::parse(&script_text)?;

let rule = EncodingRule;
let analysis = ScriptAnalysis::analyze(&script).unwrap();
let issues = rule.check_script(&analysis);
assert!(!issues.is_empty()); // Should detect the control character