Module incremental

Incremental parsing utilities for efficient text updates

Structs

TextChange
Represents a text change in the source

Functions

adjust_range_for_change
Adjust a byte range for a text change
calculate_line_number
Calculate the line number for a given byte position
calculate_line_range
Calculate line range from byte range in source text
find_section_end
Find the end of a section (start of next section or end of file)
find_section_header_start
Find the start of a section header before the given position