calculate_delta

Function calculate_delta 

pub fn calculate_delta<'a>(
    old_script: &Script<'a>,
    new_script: &Script<'a>,
) -> ScriptDelta<'a>
Available on crate feature stream only.
Calculate differences between two Scripts

Analyzes the differences between old and new scripts and returns a delta containing the minimal set of changes needed to transform the old script into the new one.

Arguments

  • old_script - The original script
  • new_script - The updated script

Returns

A ScriptDelta describing the changes