parse_section_with_context

Function parse_section_with_context 

pub fn parse_section_with_context<'a>(
    section_type: SectionType,
    text: &'a str,
    line_offset: u32,
    existing_formats: &SectionFormats<'a>,
) -> ParseResult<Section<'a>>
Parse a specific section type from text with context

Errors

Returns ParseError::MissingFormat if required format is not provided Returns ParseError::UnsupportedSection for Fonts/Graphics sections Returns other parse errors from section-specific parsers