StreamingParser

Struct StreamingParser 

pub struct StreamingParser { /* private fields */ }
Available on crate feature stream only.
High-performance streaming parser for ASS scripts

Processes input chunks incrementally using a state machine approach. Supports partial lines, incomplete sections, and memory-efficient parsing.

Implementations

Source

impl StreamingParser

pub const fn new() -> Self

Create new streaming parser

pub fn with_capacity(capacity: usize) -> Self

Create parser with custom capacity

pub fn feed_chunk(&mut self, chunk: &[u8]) -> Result<Vec<ParseDelta<'static>>>

Feed chunk of data to parser

Errors

Returns an error if the chunk contains invalid UTF-8 or parsing fails.

pub fn finish(self) -> Result<StreamingResult>

Finish parsing and return final result

Errors

Returns an error if the final line processing fails.

pub fn reset(&mut self)

Reset parser state for reuse

pub const fn peak_memory(&self) -> usize

Available on crate feature benches only.

Get peak memory usage (benchmarks only)