pub struct TokenScanner<'a> { /* private fields */ }Expand description
Scanner for different token types
Implementations
Sourceimpl<'a> TokenScanner<'a>
impl<'a> TokenScanner<'a>
Sourcepub fn new(source: &'a str, position: usize, line: usize, column: usize) -> Self
pub fn new(source: &'a str, position: usize, line: usize, column: usize) -> Self
Create new token scanner
Get current navigator state (mutable)
Get current navigator state (immutable)
Sourcepub fn scan_section_header(&mut self) -> Result<TokenType>
pub fn scan_section_header(&mut self) -> Result<TokenType>
Sourcepub fn scan_style_override(&mut self) -> Result<TokenType>
pub fn scan_style_override(&mut self) -> Result<TokenType>
Sourcepub fn scan_comment(&mut self) -> Result<TokenType>
pub fn scan_comment(&mut self) -> Result<TokenType>
Sourcepub fn scan_text(&mut self, context: TokenContext) -> Result<TokenType>
pub fn scan_text(&mut self, context: TokenContext) -> Result<TokenType>
Sourcepub fn scan_field_value(&mut self) -> Result<TokenType>
pub fn scan_field_value(&mut self) -> Result<TokenType>
Scan field value content in field value context
In field value context, colons are not delimiters (for time formats) and we consume until comma, newline, or end of input.
Errors
Returns an error if character navigation fails.