create_hasher

Function create_hasher 

pub fn create_hasher() -> AHasher
Create a hasher instance for manual hashing operations

Returns an ahash hasher with random seed for DoS resistance. Use this when you need to hash individual values outside of HashMap.

Example

use std::hash::{Hash, Hasher};
use ass_core::utils::create_hasher;

let mut hasher = create_hasher();
"some string".hash(&mut hasher);
let hash_value = hasher.finish();