Enum IssueSeverity

pub enum IssueSeverity {
    Info,
    Warning,
    Error,
    Critical,
}
Parse issue severity levels for partial recovery

Determines how serious an issue is and whether it should block processing. Lower severity issues can often be ignored or worked around.

Variants



Info

Information that may be useful but doesn’t affect functionality



Warning

Warning about potential problems or non-standard usage



Error

Error that was recovered from but may affect rendering



Critical

Critical error that will likely cause rendering problems