Incremental parsing utilities for efficient text updates
Structs
- Text
Change - Represents a text change in the source
Functions
- adjust_
range_ for_ change - Adjust a byte range for a text change
- calculate_
line_ number - Calculate the line number for a given byte position
- calculate_
line_ range - Calculate line range from byte range in source text
- find_
section_ end - Find the end of a section (start of next section or end of file)
- find_
section_ header_ start - Find the start of a section header before the given position