Struct TokenScanner

pub struct TokenScanner<'a> { /* private fields */ }
Scanner for different token types

Implementations

Source

impl<'a> TokenScanner<'a>

pub fn new(source: &'a str, position: usize, line: usize, column: usize) -> Self

Create new token scanner

pub fn navigator_mut(&mut self) -> &mut CharNavigator<'a>

Get current navigator state (mutable)

pub const fn navigator(&self) -> &CharNavigator<'a>

Get current navigator state (immutable)

pub fn scan_section_header(&mut self) -> Result<TokenType>

Scan section header like [Script Info]

Errors

Returns an error if character navigation fails.

pub fn scan_style_override(&mut self) -> Result<TokenType>

Scan style override block like {\b1\i1}

Errors

Returns an error if character navigation fails.

pub fn scan_comment(&mut self) -> Result<TokenType>

Scan comment line starting with ; or !:

Errors

Returns an error if character navigation fails.

pub fn scan_text(&mut self, context: TokenContext) -> Result<TokenType>

Scan general text content

Errors

Returns an error if character navigation fails.

pub fn scan_field_value(&mut self) -> Result<TokenType>

Scan field value content in field value context

In field value context, colons are not delimiters (for time formats) and we consume until comma, newline, or end of input.

Errors

Returns an error if character navigation fails.