pub fn normalize_field_value(value: &str) -> &str
Trim and normalize whitespace in ASS field values
ASS fields may have inconsistent whitespace that should be normalized while preserving intentional spacing in text content.